  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.2307/41409963', citation: "Ayyagari, Grover, & Purvis. (2011). Technostress: Technological Antecedents and Implications. MIS Quarterly, 35(4), 831."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Usefulness', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Complexity', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Reliability', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Presenteeism', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Anonymity', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Pace of change', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Work-home conflict', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Invasion of privacy', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Work overload', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Role ambiguity', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Job insecurity', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Strain', elementType: 'Construct'});

  // Create definitions of constructs and concepts
  CREATE (:Definition {DefinitionName: 'Strain', definition:"Strain is defined as an individual’s psychological response to the stressors (Cooper et al. 2001)"});
  CREATE (:Definition {DefinitionName: 'Work overload', definition:"Work overload is the perception that assigned work exceeds an individual’s capability or skill level (Cooper et al. 2001; Moore 2000)."});
  CREATE (:Definition {DefinitionName: 'Role ambiguity', definition:"Role ambiguity is the unpredictability of the consequences of one’s role performance and lack of information needed to perform the role (Cooper et al. 2001; Jex 1998; Kahn et al. 1964)."});
  CREATE (:Definition {DefinitionName: 'Job insecurity', definition:"Job insecurity is the perception of the threat of job loss (Ashford et al. 1989; Burke and Cooper 2000; Cooper et al. 2001)."});
  CREATE (:Definition {DefinitionName: 'Work-home conflict', definition:"Work–home conflict is the perceived conflict between the demands of work and family (Cooper et al. 2001; Kreiner 2006; Netemeyer et al. 1996)"});
  CREATE (:Definition {DefinitionName: 'Invasion of privacy', definition:"Invasion of privacy involves the perception that an individual’s privacy has been compromised (Alge 2001; Eddy et al. 1999)."});
  CREATE (:Definition {DefinitionName: 'Usefulness', definition:"Degree to which characteristics of technology enhance job performance"});
  CREATE (:Definition {DefinitionName: 'Complexity', definition:"Degree to which use of technology is free of effort"});
  CREATE (:Definition {DefinitionName: 'Reliability', definition:"Degree to which features and capabilities provided by the technology are dependable"});
  CREATE (:Definition {DefinitionName: 'Pace of change', definition:"Degree to which an individual perceives tech- nological changes to be rapid"});
  CREATE (:Definition {DefinitionName: 'Presenteeism', definition:"Degree to which tech- nologies enable individuals to be reachable"});
  CREATE (:Definition {DefinitionName: 'Anonymity', definition:"Degree to which exact use of technology could be identifiable"});

  // Create a relationships between a publication and definitions it contains
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Definition {DefinitionName: 'Strain'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Definition {DefinitionName: 'Work overload'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Definition {DefinitionName: 'Role ambiguity'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Definition {DefinitionName: 'Job insecurity'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Definition {DefinitionName: 'Work-home conflict'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Definition {DefinitionName: 'Invasion of privacy'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Definition {DefinitionName: 'Usefulness'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Definition {DefinitionName: 'Complexity'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Definition {DefinitionName: 'Reliability'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Definition {DefinitionName: 'Pace of change'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Definition {DefinitionName: 'Presenteeism'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Definition {DefinitionName: 'Anonymity'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;


  // Create relationships between definitions and constructs
  MATCH (a:Element {elementName: 'Strain'}), (b:Definition {DefinitionName: 'Strain'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Work overload'}), (b:Definition {DefinitionName: 'Work overload'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Role ambiguity'}), (b:Definition {DefinitionName: 'Role ambiguity'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Job insecurity'}), (b:Definition {DefinitionName: 'Job insecurity'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Work-home conflict'}), (b:Definition {DefinitionName: 'Work-home conflict'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Invasion of privacy'}), (b:Definition {DefinitionName: 'Invasion of privacy'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Usefulness'}), (b:Definition {DefinitionName: 'Usefulness'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Complexity'}), (b:Definition {DefinitionName: 'Complexity'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Reliability'}), (b:Definition {DefinitionName: 'Reliability'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Pace of change'}), (b:Definition {DefinitionName: 'Pace of change'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Presenteeism'}), (b:Definition {DefinitionName: 'Presenteeism'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Anonymity'}), (b:Definition {DefinitionName: 'Anonymity'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;


  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='56e5478b-02c6-4d64-8cfc-34930da04f67';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.2307/41409963"}),(g:Model)
  WHERE g.id IN ['56e5478b-02c6-4d64-8cfc-34930da04f67']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: '56e5478b-02c6-4d64-8cfc-34930da04f67'}),(e:Element)
  WHERE e.elementName IN [  'Usefulness','Complexity','Reliability','Presenteeism', 'Anonymity','Pace of change', 'Work-home conflict','Invasion of privacy','Work overload','Role ambiguity','Job insecurity','Strain']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Usefulness'}),(b:Element {elementName: 'Work overload'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Complexity'}),(b:Element {elementName: 'Work overload'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Reliability'}),(b:Element {elementName: 'Work overload'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Presenteeism'}),(b:Element {elementName: 'Work-home conflict'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Presenteeism'}),(b:Element {elementName: 'Invasion of privacy'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Presenteeism'}),(b:Element {elementName: 'Work overload'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Presenteeism'}),(b:Element {elementName: 'Role ambiguity'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Anonymity'}),(b:Element {elementName: 'Invasion of privacy'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Pace of change'}),(b:Element {elementName: 'Work overload'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Pace of change'}),(b:Element {elementName: 'Role ambiguity'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Pace of change'}),(b:Element {elementName: 'Job insecurity'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Work-home conflict'}),(b:Element {elementName: 'Strain'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Work overload'}),(b:Element {elementName: 'Strain'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Role ambiguity'}),(b:Element {elementName: 'Strain'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Job insecurity'}),(b:Element {elementName: 'Strain'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Invasion of privacy'}),(b:Element {elementName: 'Strain'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;

  // Create the authors
  CREATE (:Author {ORCID: '0000-0003-2518-964X',authorFirst: 'Ramakrishna', authorLast: 'Ayyagari', id:"e2f182c5-ee3f-4e27-bf09-b9feebcb8e7d"});
  CREATE (:Author {authorFirst: 'Varun ', authorLast: 'Grover', id:"74ba035b-10fb-4a61-a60e-ad0ec6e49a7e"});
  CREATE (:Author {ORCID: '0000-0003-4812-0821',authorFirst: 'Russell', authorLast: 'Purvis', id:"de600be2-7d03-4eba-a3c5-db94c8508a94"});

  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Author {id: 'e2f182c5-ee3f-4e27-bf09-b9feebcb8e7d'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Author {id: '74ba035b-10fb-4a61-a60e-ad0ec6e49a7e'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409963'}), (a:Author {id: 'de600be2-7d03-4eba-a3c5-db94c8508a94'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
