  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.2307/41409970', citation: "Smith, Dinev, & Xu. (2011). Information Privacy Research: An Interdisciplinary Review. MIS Quarterly, 35(4), 989."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Privacy experiences', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Privacy awareness', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Personality differences', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Demographic differences', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Culture/ climate', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Privacy Concerns', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Regulation', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Behavioral reactions', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Trust', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Privacy notice/ seal', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Privacy calculus', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Risks/Costs', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Benefits', elementType: 'Construct'});

  // Create definitions of constructs and concepts
  CREATE (:Definition {DefinitionName: 'Privacy awareness', definition:"Privacy awareness reflects the extent to which an individual is informed about organizational privacy practices (Malhotra et al. 2004; Phelps et al. 2000).",id:"ed9a3c0d-2e78-425e-bee8-142b464c3585"});
  CREATE (:Definition {DefinitionName: 'Personality differences', definition:"Personality differences such as introversion versus extroversion (Lu et al. 2004), independent-self versus interdependent-self (Xu 2007), and “big-five” personality traits7 (Bansal et al. 2010)",id:"138b8b61-041d-48d1-b0ce-483db93e56e8"});
  CREATE (:Definition {DefinitionName: 'Risks/Costs', definition:"Privacy risk has been defined as the degree to which an individual believes that a high potential for loss is associated with the release of personal information to a firm (Featherman and Pavlou 2003; Malhotra et al. 2004).",id:"48191274-30fd-49e6-b44a-597ae5934018"});

  // Create a relationships between a publication and definitions it contains
  MATCH (p:Publication {DOI: '10.2307/41409970'}), (a:Definition {id: 'ed9a3c0d-2e78-425e-bee8-142b464c3585'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409970'}), (a:Definition {id: '138b8b61-041d-48d1-b0ce-483db93e56e8'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409970'}), (a:Definition {id: '48191274-30fd-49e6-b44a-597ae5934018'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;

  // Create relationships between definitions and constructs
  MATCH (a:Element {elementName: 'Privacy awareness'}), (b:Definition {id: 'ed9a3c0d-2e78-425e-bee8-142b464c3585'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Personality differences'}), (b:Definition {id: '138b8b61-041d-48d1-b0ce-483db93e56e8'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Risks/Costs'}), (b:Definition {id: '48191274-30fd-49e6-b44a-597ae5934018'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;

  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='3f2ab565-5eeb-4f5c-a860-9ca13729e8f7';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.2307/41409970"}),(g:Model)
  WHERE g.id IN ['3f2ab565-5eeb-4f5c-a860-9ca13729e8f7']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: '3f2ab565-5eeb-4f5c-a860-9ca13729e8f7'}),(e:Element)
  WHERE e.elementName IN ['Privacy experiences', 'Privacy awareness', 'Personality differences', 'Demographic differences', 'Culture/ climate', 'Privacy Concerns', 'Regulation', 'Behavioral reactions', 'Trust', 'Privacy notice/ seal', 'Privacy calculus', 'Risks/Costs', 'Benefits']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Privacy experiences'}),(b:Element {elementName: 'Privacy Concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Privacy awareness'}),(b:Element {elementName: 'Privacy Concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Personality differences'}),(b:Element {elementName: 'Privacy Concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Demographic differences'}),(b:Element {elementName: 'Privacy Concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Culture/ climate'}),(b:Element {elementName: 'Privacy Concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Privacy Concerns'}),(b:Element {elementName: 'Regulation'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Regulation'}),(b:Element {elementName: 'Privacy Concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Privacy Concerns'}),(b:Element {elementName: 'Behavioral reaction'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Privacy Concerns'}),(b:Element {elementName: 'Trust'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Trust'}),(b:Element {elementName: 'Privacy Concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Trust'}),(b:Element {elementName: 'Behavioral reaction'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName:  "Privacy Concerns"}),(b:Element {elementName:  "Trust"}),(c:Element {elementName: "Behavioral reaction"})
  CREATE (a)-[r1:RELATES_TO {type: 'moderates' , model: 'Research model'}]->(b)-[r2:RELATES_TO {type: 'moderates', model: 'Research model'}]->(c)
  RETURN r1, r2;
  MATCH (a:Element {elementName: 'Privacy notice/ seal'}),(b:Element {elementName: 'Trust'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Privacy calculus'}),(b:Element {elementName: 'Behavioral reaction'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Risks/Costs'}),(b:Element {elementName: 'Privacy calculus'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Benefits'}),(b:Element {elementName: 'Privacy calculus'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Privacy Concerns'}),(b:Element {elementName: 'Risks/Costs'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;

  // Create the authors
  CREATE (:Author {ORCID: '0000-0003-3025-1524',authorFirst: 'H. Jeff', authorLast: 'Smith', id:"6b4cb33a-595b-4e14-9166-83499021932b"});
  CREATE (:Author {authorFirst: 'Tamara', authorLast: 'Dinev', id:"fa1de621-de12-4ac8-a7ce-72594d09e5c7"});
  CREATE (:Author {authorFirst: 'Heng', authorLast: 'Xu', id:"7cb58860-dba8-4a29-9f9a-4b5ebdd8f5b4"});

  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.2307/41409970'}), (a:Author {id: '6b4cb33a-595b-4e14-9166-83499021932b'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409970'}), (a:Author {id: 'fa1de621-de12-4ac8-a7ce-72594d09e5c7'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/41409970'}), (a:Author {id: '7cb58860-dba8-4a29-9f9a-4b5ebdd8f5b4'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 3}]->(a)
  RETURN r;

  // Create theories referenced in the publication and related them to elements.
  CREATE (:Theory {theoryTitle: 'Elaboration likelihood model'});
  MATCH (t:Theory {theoryTitle: 'Elaboration likelihood model'}), (p:Publication {DOI: '10.2307/41409970'})
  CREATE (p)-[r:DRAWS_ON]->(t)
  RETURN r;
