  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.25300/misq/2013/37.1.12', citation: "Hong, W., & Thong, J. Y. L. (2013). Internet Privacy Concerns:  An Integrated Conceptualization and Four Empirical Studies. MIS Quarterly, 37(1), 275–298."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Trusting beliefs', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Risk beliefs', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Internet privacy concerns', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Interaction management', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Information management', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Collection', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Secondary usage', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Control', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Errors', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Improper access', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Awareness', elementType: 'Construct'});

  // Create definitions of constructs and concepts
  CREATE (:Definition {DefinitionName: 'Internet privacy concerns', definition:"Internet privacy concerns is defined as the degree to which an Internet user is concerned about website practices related to the collection and use of his or her personal information."});
  CREATE (:Definition {DefinitionName: 'Interaction management', definition:"the ability of an individual to manage the collection and sub- sequent use of his or her personal information by websites."});
  CREATE (:Definition {DefinitionName: 'Collection', definition:"collection is the degree to which a person is concerned about the amount of individual-specific data possessed by websites (Malhotra et al. 2004)"});
  CREATE (:Definition {DefinitionName: 'Secondary usage', definition:"Secondary usage is the degree to which a person is concerned that personal information is collected by websites for one purpose but is used for another, secondary purpose without authorization from the individual (Smith et al. 1996)"});
  CREATE (:Definition {DefinitionName: 'Errors', definition:"Errors is the degree to which a person is concerned that protections against deliberate and accidental errors in personal data collected by websites are inadequate (Smith et al. 1996)."});
  CREATE (:Definition {DefinitionName: 'Improper access', definition:"Improper access is the degree to which a person is concerned that personal information held by web- sites is readily available to people not properly authorized to view or work with the data (Smith et al. 1996)."});
  CREATE (:Definition {DefinitionName: 'Control', definition:"Control is the degree to which a person is concerned that he/she does not have adequate control over his/her personal information held by websites (Malhotra et al. 2004)."});
  CREATE (:Definition {DefinitionName: 'Awareness', definition:"Awareness is the degree to which a person is concerned about his/her aware- ness of information privacy practices by websites (Malhotra et al. 2004)."});

  // Create a relationships between a publication and definitions it contains
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.1.12'}), (a:Definition {DefinitionName: 'Internet privacy concerns'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.1.12'}), (a:Definition {DefinitionName: 'Interaction management'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.1.12'}), (a:Definition {DefinitionName: 'Collection'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.1.12'}), (a:Definition {DefinitionName: 'Secondary usage'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.1.12'}), (a:Definition {DefinitionName: 'Errors'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.1.12'}), (a:Definition {DefinitionName: 'Improper access'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.1.12'}), (a:Definition {DefinitionName: 'Control'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.1.12'}), (a:Definition {DefinitionName: 'Awareness'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;

  // Create relationships between definitions and constructs
  MATCH (a:Element {elementName: 'Internet privacy concerns'}), (b:Definition {DefinitionName: 'Internet privacy concerns'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Interaction management'}), (b:Definition {DefinitionName: 'Interaction management'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Collection'}), (b:Definition {DefinitionName: 'Collection'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Secondary usage'}), (b:Definition {DefinitionName: 'Secondary usage'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Errors'}), (b:Definition {DefinitionName: 'Errors'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Improper access'}), (b:Definition {DefinitionName: 'Improper access'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Control'}), (b:Definition {DefinitionName: 'Control'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Awareness'}), (b:Definition {DefinitionName: 'Awareness'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;

  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='b11c45b6-afdb-46ce-a35d-706a3a9191e7';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.25300/misq/2013/37.1.12"}),(g:Model)
  WHERE g.id IN ['b11c45b6-afdb-46ce-a35d-706a3a9191e7']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: 'b11c45b6-afdb-46ce-a35d-706a3a9191e7'}),(e:Element)
  WHERE e.elementName IN ['Trusting beliefs', 'Risk beliefs', 'Internet privacy concerns', 'Interaction management', 'Information management', 'Collection', 'Secondary usage', 'Control', 'Errors', 'Improper access', 'Awareness']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Internet privacy concerns'}),(b:Element {elementName: 'Trusting beliefs'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Internet privacy concerns'}),(b:Element {elementName: 'Risk beliefs'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Internet privacy concerns'}),(b:Element {elementName: 'Interaction management'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Internet privacy concerns'}),(b:Element {elementName: 'Information management'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Internet privacy concerns'}),(b:Element {elementName: 'Awareness'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Interaction management'}),(b:Element {elementName: 'Collection'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Interaction management'}),(b:Element {elementName: 'Secondary usage'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Interaction management'}),(b:Element {elementName: 'Control'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Information management'}),(b:Element {elementName: 'Errors'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Information management'}),(b:Element {elementName: 'Improper access'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;

  // Create the authors
  CREATE (:Author {ORCID: '0000-0001-8511-7395',authorFirst: 'Weiyin', authorLast: 'Hong', id:"95f1d55e-24af-4f2a-bb96-31c7f5bbb86a"});
  CREATE (:Author {authorFirst: 'James', authorLast: 'Thong', id:"55eca2d3-2f12-4e62-bee6-33a68ccc957a"});

  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.1.12'}), (a:Author {id: '95f1d55e-24af-4f2a-bb96-31c7f5bbb86a'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.1.12'}), (a:Author {id: '55eca2d3-2f12-4e62-bee6-33a68ccc957a'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
