  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.25300/misq/2013/37.4.07', citation: "Sutanto, J., Palme, E., Tan, C.-H., … Phang, C. W. (2013). Addressing the Personalization-Privacy Paradox:  An Empirical Assessment from a Field Experiment on Smartphone Users. MIS Quarterly, 37(4), 1141–1164."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Provision of a personalization feature', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Process gratification', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Content gratification', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Provision of a privacy-safe feature', elementType: 'Construct'});

  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='be7f147e-7437-4a0e-a3b3-804db87fb1df';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.25300/misq/2013/37.4.07"}),(g:Model)
  WHERE g.id IN ['be7f147e-7437-4a0e-a3b3-804db87fb1df']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: 'be7f147e-7437-4a0e-a3b3-804db87fb1df'}),(e:Element)
  WHERE e.elementName IN ['Provision of a personalization feature','Process gratification','Content gratification','Provision of a privacy-safe feature']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Provision of a personalization feature'}),(b:Element {elementName: 'Process gratification'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Provision of a personalization feature'}),(b:Element {elementName: 'Content gratification'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Provision of a privacy-safe feature'}),(b:Element {elementName: 'Process gratification'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Provision of a privacy-safe feature'}),(b:Element {elementName: 'Content gratification'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;


  // Create the authors
  CREATE (:Author {ORCID: '0000-0002-1587-5948',authorFirst: 'Juliana', authorLast: 'Sutanto', id:"3e21b88c-8c97-4703-bcc1-e4b708f426a9"});
  CREATE (:Author {authorFirst: 'Elia', authorLast: 'Palme', id:"30a94a39-013e-4a40-9856-95767ca001f9"});
  CREATE (:Author {ORCID: '0000-0003-3870-4591',authorFirst: 'Chuan-Hoo', authorLast: 'Tan', id:"cae4361f-8f35-46b4-85f9-7550db8f11b6"});
  CREATE (:Author {ORCID: '0000-0002-6375-3443',authorFirst: 'Chee Wei', authorLast: 'Phang', id:"29eb9325-a240-4614-955d-23dd90d9dea4"});

  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.4.07'}), (a:Author {id: '3e21b88c-8c97-4703-bcc1-e4b708f426a9'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.4.07'}), (a:Author {id: '30a94a39-013e-4a40-9856-95767ca001f9'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.4.07'}), (a:Author {id: 'cae4361f-8f35-46b4-85f9-7550db8f11b6'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2013/37.4.07'}), (a:Author {id: '29eb9325-a240-4614-955d-23dd90d9dea4'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;

  // Create theories referenced in the publication and related them to elements.
  CREATE (:Theory {theoryTitle: 'Uses and gratifications theory'});
  MATCH (t:Theory {theoryTitle: 'Uses and gratifications theory'}), (p:Publication {DOI: '10.25300/misq/2013/37.4.07'})
  CREATE (p)-[r:DRAWS_ON]->(t)
  RETURN r;
  CREATE (:Theory {theoryTitle: 'Information boundary theory'});
  MATCH (t:Theory {theoryTitle: 'Information boundary theory'}), (p:Publication {DOI: '10.25300/misq/2013/37.4.07'})
  CREATE (p)-[r:DRAWS_ON]->(t)
  RETURN r;
