  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.25300/misq/2017/41.1.02', citation: "Koh, B., Raghunathan, S., & Nault, B. R. (2017). Is Voluntary Profiling Welfare Enhancing? MIS Quarterly, 41(1), 23–41."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Voluntary profiling', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Lower price paid by consumers', elementType: 'Variable'});
  CREATE (:Element {elementName: 'Larger consumer surplus', elementType: 'Construct'});


  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='ff293e4f-5657-4a56-a821-c01dc90600ca';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.25300/misq/2017/41.1.02"}),(g:Model)
  WHERE g.id IN ['ff293e4f-5657-4a56-a821-c01dc90600ca']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: 'ff293e4f-5657-4a56-a821-c01dc90600ca'}),(e:Element)
  WHERE e.elementName IN ['Voluntary profiling','Lower price paid by consumers','Larger consumer surplus']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Voluntary profiling'}),(b:Element {elementName: 'Lower price paid by consumers'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Voluntary profiling'}),(b:Element {elementName: 'Larger consumer surplus'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;

  // Create the authors
  CREATE (:Author {ORCID: '0000-0002-4046-1712',authorFirst: 'Byungwan', authorLast: 'Koh', id:"249b9b8c-4258-4f1f-8bf1-f23ebb8a3f1f"});
  CREATE (:Author {ORCID: '0000-0002-2782-3520',authorFirst: 'Srinivasan', authorLast: 'Raghunathan', id:"a00210e1-6545-457a-b418-d91e2dfdd0e7"});
  CREATE (:Author {ORCID: '0000-0001-7856-885X',authorFirst: 'Barrie', authorLast: 'Nault', id:"51cc143a-8145-4b4f-bf4d-54568b6bf264"});

  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.25300/misq/2017/41.1.02'}), (a:Author {id: '249b9b8c-4258-4f1f-8bf1-f23ebb8a3f1f'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2017/41.1.02'}), (a:Author {id: 'a00210e1-6545-457a-b418-d91e2dfdd0e7'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2017/41.1.02'}), (a:Author {id: '51cc143a-8145-4b4f-bf4d-54568b6bf264'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 3}]->(a)
  RETURN r;
