  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.25300/misq/2018/13839', citation: "Gopal, R. D., Hidaji, H., Patterson, R. A., Rolland, E., … Zhdanov, D. (2018). How Much to Share with Third Parties?  User Privacy Concerns and Website Dilemmas. MIS Quarterly, 42(1), 143–164."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'User privacy concerns', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Third-party revenue from user information', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Website differentiation', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Total number of potential users in market', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Total number of potential third-parties in market', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Optimal publisher website royalty', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Optimal publisher website price', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Maximum third party fixed cost', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Optimal number of third parties on publisher website', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Optimal number of users on publisher website', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Optimal publisher website profit', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Total user surplus', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Total third-party surplus', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Taxation on royalties', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Taxation on prices', elementType: 'Construct'});


  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='cc71f803-93e1-44a9-9297-40cd3cbd7f91';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.25300/misq/2018/13839"}),(g:Model)
  WHERE g.id IN ['cc71f803-93e1-44a9-9297-40cd3cbd7f91']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: 'cc71f803-93e1-44a9-9297-40cd3cbd7f91'}),(e:Element)
  WHERE e.elementName IN ['User privacy concerns', 'Third-party revenue from user information', 'Website differentiation', 'Total number of potential users in market', 'Total number of potential third-parties in market', 'Optimal publisher website royalty', 'Optimal publisher website price', 'Maximum third party fixed cost', 'Optimal number of third parties on publisher website', 'Optimal number of users on publisher website', 'Optimal publisher website profit', 'Total user surplus', 'Total third-party surplus', 'Taxation on royalties', 'Taxation on prices']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'User privacy concerns'}),(b:Element {elementName: 'Optimal publisher website price'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'User privacy concerns'}),(b:Element {elementName: 'Optimal publisher website royalty'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Third-party revenue from user information'}),(b:Element {elementName: 'Optimal publisher website price'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Third-party revenue from user information'}),(b:Element {elementName: 'Optimal publisher website royalty'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Website differentiation'}),(b:Element {elementName: 'Optimal publisher website price'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Total number of potential users in market'}),(b:Element {elementName: 'Optimal publisher website price'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Total number of potential third-parties in market'}),(b:Element {elementName: 'Optimal publisher website price'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'User privacy concerns'}),(b:Element {elementName: 'Optimal number of third parties on publisher website'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Third-party revenue from user information'}),(b:Element {elementName: 'Optimal number of third parties on publisher website'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Maximum third party fixed cost'}),(b:Element {elementName: 'Optimal number of third parties on publisher website'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Total number of potential users in market'}),(b:Element {elementName: 'Optimal number of third parties on publisher website'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Total number of potential third-parties in market'}),(b:Element {elementName: 'Optimal number of third parties on publisher website'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Total number of potential users in market'}),(b:Element {elementName: 'Optimal number of users on publisher website'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'User privacy concerns'}),(b:Element {elementName: 'Optimal publisher website profit'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'User privacy concerns'}),(b:Element {elementName: 'Total user surplus'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'User privacy concerns'}),(b:Element {elementName: 'Total third-party surplus'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Taxation on royalties'}),(b:Element {elementName: 'Optimal publisher website royalty'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Taxation on royalties'}),(b:Element {elementName: 'Optimal publisher website price'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Taxation on prices'}),(b:Element {elementName: 'Optimal publisher website royalty'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Taxation on prices'}),(b:Element {elementName: 'Optimal publisher website price'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Taxation on royalties'}),(b:Element {elementName: 'Optimal publisher website profit'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Taxation on royalties'}),(b:Element {elementName: 'Total user surplus'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Taxation on royalties'}),(b:Element {elementName: 'Total third-party surplus'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Taxation on prices'}),(b:Element {elementName: 'Optimal publisher website profit'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Taxation on prices'}),(b:Element {elementName: 'Total user surplus'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Taxation on prices'}),(b:Element {elementName: 'Total third-party surplus'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;


  // Create the authors
  CREATE (:Author {ORCID: '0000-0003-1925-4118',authorFirst: 'Ram', authorLast: 'Gopal', id:"fa09022d-04f0-401c-8cd2-7faef9d7ab95"});
  CREATE (:Author {authorFirst: 'Hooman', authorLast: 'Hidaji', id:"60376364-5fd9-419e-86de-7846af89a1d5"});
  CREATE (:Author {ORCID: '0000-0001-5408-6485',authorFirst: 'Raymond', authorLast: 'Patterson', id:"eb3ff1c9-0847-4400-82ba-cae50881d9b2"});
  CREATE (:Author {ORCID: '0000-0002-6375-0592',authorFirst: 'Erik', authorLast: 'Rolland', id:"fc1bf9aa-841a-44a8-bbcd-8ae91832e27a"});
  CREATE (:Author {ORCID: '0000-0002-3349-7581',authorFirst: 'Dmitry', authorLast: 'Zhdanov', id:"4be91d70-c8ae-4f6c-8a96-b95299af78da"});


  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.25300/misq/2018/13839'}), (a:Author {id: 'fa09022d-04f0-401c-8cd2-7faef9d7ab95'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2018/13839'}), (a:Author {id: '60376364-5fd9-419e-86de-7846af89a1d5'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2018/13839'}), (a:Author {id: 'eb3ff1c9-0847-4400-82ba-cae50881d9b2'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2018/13839'}), (a:Author {id: 'fc1bf9aa-841a-44a8-bbcd-8ae91832e27a'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 3}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2018/13839'}), (a:Author {id: '4be91d70-c8ae-4f6c-8a96-b95299af78da'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 4}]->(a)
  RETURN r;
