  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.25300/misq/2018/14316', citation: "Adjerid, I., Peer, E., & Acquisti, A. (2018). Beyond the Privacy Paradox: Objective Versus Relative Risk in Privacy Decision Making. MIS Quarterly, 42(2), 465–488."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Objective levels of privacy protection', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Disclosure of personal information', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Relative perception of levels of privacy protection', elementType: 'Construct'});


  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='192f59b7-f518-4604-8772-1975ddb9cb99';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.25300/misq/2018/14316"}),(g:Model)
  WHERE g.id IN ['192f59b7-f518-4604-8772-1975ddb9cb99']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: '192f59b7-f518-4604-8772-1975ddb9cb99'}),(e:Element)
  WHERE e.elementName IN ['Objective levels of privacy protection', 'Disclosure of personal information', 'Relative perception of levels of privacy protection']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Objective levels of privacy protection'}),(b:Element {elementName:'Disclosure of personal information'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Relative perception of levels of privacy protection'}),(b:Element {elementName:'Disclosure of personal information'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;

  // Create the authors
  CREATE (:Author {ORCID: '0000-0002-2786-1244',authorFirst: 'Idris', authorLast: 'Adjerid', id:"5548c1d3-c456-414a-813d-475a38d71bec"});
  CREATE (:Author {authorFirst: 'Eyal', authorLast: 'Peer', id:"ee334260-a3f7-43ab-b68a-e03753d7a098"});
  CREATE (:Author {ORCID: '0000-0001-6582-6178',authorFirst: 'Alessandro', authorLast: 'Acquisti', id:"825c59d5-fdcd-49e5-b506-56a11716c51e"});

  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.25300/misq/2018/14316'}), (a:Author {id: '5548c1d3-c456-414a-813d-475a38d71bec'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2018/14316'}), (a:Author {id: 'ee334260-a3f7-43ab-b68a-e03753d7a098'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2018/14316'}), (a:Author {id: '825c59d5-fdcd-49e5-b506-56a11716c51e'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 3}]->(a)
  RETURN r;


  // Create theories referenced in the publication and related them to elements.
  CREATE (:Theory {theoryTitle: 'Prospect theory'});
  MATCH (t:Theory {theoryTitle: 'Prospect theory'}), (p:Publication {DOI: '10.25300/misq/2018/14316'})
  CREATE (p)-[r:DRAWS_ON]->(t)
  RETURN r;
