  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.25300/misq/2019/12112', citation: "Wunderlich, P., Veit, D. J., & Sarker, S. (2019). Adoption of Sustainable Technologies: A Mixed-Methods Study of German Households. MIS Quarterly, 43(2), 673–691."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Attitude toward smart metering technology', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Intention to use smart metering technology', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Internal perceived locus of control', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Intention to adopt smart metering technology', elementType: 'Construct'});
  CREATE (:Element {elementName: 'External perceived locus of control', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Introjected perceived locus of control', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Income', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Household size', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Age', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Education', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Electricity costs per month', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Annual electricity consumption', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Extent to which consumers have switched electricity providers', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Perceived privacy risk', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Inherent innovativeness', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Willingness to pay for energy efficient innovations', elementType: 'Construct'});


  // Create definitions of constructs and concepts
  CREATE (:Definition {DefinitionName: 'Intention to adopt smart metering technology', definition:"The subjective probability that a person will perform the behavior of adopting smart metering technology."});
  CREATE (:Definition {DefinitionName: 'Attitude toward smart metering technology', definition:"The affective or evaluative judgment of the consumer toward smart metering technology."});
  CREATE (:Definition {DefinitionName: 'Internal perceived locus of control', definition:"Feelings of volition where consumers perceive themselves as the “origin” of their behavior."});
  CREATE (:Definition {DefinitionName: 'External perceived locus of control', definition:"Perceived reasons for one’s behavior that are attributed to external authority or compliance. This assumes that no conflict exists between perceived external influences and personal values of the user."});
  CREATE (:Definition {DefinitionName: 'Introjected perceived locus of control', definition:"Theorized to be caused by misalignment of perceived social influences and personal values. Such motivation are related to affective feelings of guilt and shame and esteem-based pressures to act on one hand, and feelings of the self being autonomous on the other. It is often associated with strong self-imposed feelings of coercion that might lead to rejection of the “imposed” behavior."});
  CREATE (:Definition {DefinitionName: 'Perceived privacy risk', definition:"Refers to the potential loss of control over personal information, such as when information about one is used without one’s knowledge or permission."});
  CREATE (:Definition {DefinitionName: 'Age', definition:"The age of the consumers."});
  CREATE (:Definition {DefinitionName: 'Education', definition:"The level of formal education of the consumers."});
  CREATE (:Definition {DefinitionName: 'Income', definition:"The average income of the consumers."});
  CREATE (:Definition {DefinitionName: 'Household size', definition:"The number of people living in the consumer household."});
  CREATE (:Definition {DefinitionName: 'Inherent innovativeness', definition:"The extent to which consumers have curiosity and/or interest in innovations."});
  CREATE (:Definition {DefinitionName: 'Willingness to pay for energy efficient innovations', definition:"The extent to which consumers are willing to pay for new energy-related innovations."});
  CREATE (:Definition {DefinitionName: 'Annual electricity consumption', definition:"The average annual electricity consumed by the household."});
  CREATE (:Definition {DefinitionName: 'Electricity costs per month', definition:"The average electricity costs per month."});
  CREATE (:Definition {DefinitionName: 'Extent to which consumers have switched electricity providers', definition:"The number of times consumers have switched electricity providers or companies."});

  // Create a relationships between a publication and definitions it contains
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Intention to adopt smart metering technology'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Attitude toward smart metering technology'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Internal perceived locus of control'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'External perceived locus of control'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Introjected perceived locus of control'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Perceived privacy risk'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Age'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Education'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Income'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Household size'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Inherent innovativeness'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Willingness to pay for energy efficient innovations'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Annual electricity consumption'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Electricity costs per month'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Definition {DefinitionName: 'Extent to which consumers have switched electricity providers'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;

  // Create relationships between definitions and constructs
  MATCH (a:Element {elementName: 'Intention to adopt smart metering technology'}), (b:Definition {DefinitionName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Attitude toward smart metering technology'}), (b:Definition {DefinitionName: 'Attitude toward smart metering technology'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Internal perceived locus of control'}), (b:Definition {DefinitionName: 'Internal perceived locus of control'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'External perceived locus of control'}), (b:Definition {DefinitionName: 'External perceived locus of control'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Introjected perceived locus of control'}), (b:Definition {DefinitionName: 'Introjected perceived locus of control'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Perceived privacy risk'}), (b:Definition {DefinitionName: 'Perceived privacy risk'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Age'}), (b:Definition {DefinitionName: 'Age'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Education'}), (b:Definition {DefinitionName: 'Education'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Income'}), (b:Definition {DefinitionName: 'Income'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Household size'}), (b:Definition {DefinitionName: 'Household size'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Inherent innovativeness'}), (b:Definition {DefinitionName: 'Inherent innovativeness'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Willingness to pay for energy efficient innovations'}), (b:Definition {DefinitionName: 'Willingness to pay for energy efficient innovations'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Annual electricity consumption'}), (b:Definition {DefinitionName: 'Annual electricity consumption'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Electricity costs per month'}), (b:Definition {DefinitionName: 'Electricity costs per month'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Extent to which consumers have switched electricity providers'}), (b:Definition {DefinitionName: 'Extent to which consumers have switched electricity providers'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;

  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='f6b02593-6fe1-4d61-9e1f-967dd8d38e8b';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.25300/misq/2019/12112"}),(g:Model)
  WHERE g.id IN ['f6b02593-6fe1-4d61-9e1f-967dd8d38e8b']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: 'f6b02593-6fe1-4d61-9e1f-967dd8d38e8b'}),(e:Element)
  WHERE e.elementName IN ['Attitude toward smart metering technology', 'Intention to use smart metering technology', 'Internal perceived locus of control', 'Intention to adopt smart metering technology', 'External perceived locus of control', 'Introjected perceived locus of control', 'Income', 'Household size', 'Age', 'Education', 'Electricity costs per month', 'Annual electricity consumption', 'Extent to which consumers have switched electricity providers', 'Perceived privacy risk', 'Inherent innovativeness', 'Willingness to pay for energy efficient innovations']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Attitude toward smart metering technology'}),(b:Element {elementName: 'Intention to use smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Internal perceived locus of control'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'External perceived locus of control'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Introjected perceived locus of control'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Income'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Household size'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Age'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Education'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Electricity costs per month'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Annual electricity consumption'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Extent to which consumers have switched electricity providers'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Perceived privacy risk'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Inherent innovativeness'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Willingness to pay for energy efficient innovations'}),(b:Element {elementName: 'Intention to adopt smart metering technology'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;

  // Create the authors
  CREATE (:Author {ORCID: '0000-0003-4657-2883',authorFirst: 'Daniel', authorLast: 'Veit', id:"25f17e60-5056-4fba-8df5-f704b73dd74e"});
  CREATE (:Author {authorFirst: 'Philipp', authorLast: 'Wunderlich', id:"e29d660c-ebb6-4983-aaa3-65f51ed87a1d"});
  CREATE (:Author {authorFirst: 'Saonee', authorLast: 'Sarker', id:"55075720-3e63-4760-a19f-3a2e540b2793"});

  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Author {id: '25f17e60-5056-4fba-8df5-f704b73dd74e'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Author {id: 'e29d660c-ebb6-4983-aaa3-65f51ed87a1d'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.25300/misq/2019/12112'}), (a:Author {id: '55075720-3e63-4760-a19f-3a2e540b2793'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
