  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.2307/249775', citation: "Culnan, M. J. (1993). “How Did They Get My Name?”: An Exploratory Investigation of Consumer Attitudes toward Secondary Information Use. MIS Quarterly, 17(3), 341."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Concern for privacy', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Attitudes toward direct mail marketing', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Demographics', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Attitudes toward secondary information use', elementType: 'Construct'});

  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='e8368d12-efa0-4a01-8611-4b8bd34ff082';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.2307/249775"}),(g:Model)
  WHERE g.id IN ['e8368d12-efa0-4a01-8611-4b8bd34ff082']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: 'e8368d12-efa0-4a01-8611-4b8bd34ff082'}),(e:Element)
  WHERE e.elementName IN ['Concern for privacy', 'Attitudes toward direct mail marketing', 'Demographics', 'Attitudes toward secondary information use']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Concern for privacy'}),(b:Element {elementName: 'Attitudes toward secondary information use'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Attitudes toward direct mail marketing'}),(b:Element {elementName: 'Attitudes toward secondary information use'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Demographics'}),(b:Element {elementName: 'Attitudes toward secondary information use'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;

  // Create the authors
  CREATE (:Author {authorFirst: 'Mary', authorLast: 'Culnan', id:"56e3ddcf-7099-482f-b5bb-8cdcf8be0509"});

  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.2307/249775'}), (a:Author {id: '56e3ddcf-7099-482f-b5bb-8cdcf8be0509'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
