  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.2307/25148715', citation: "Awad, & Krishnan. (2006). The Personalization Privacy Paradox: An Empirical Evaluation of Information Transparency and the Willingness to Be Profiled Online for Personalization. MIS Quarterly, 30(1), 13."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Importance of information transparency', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Privacy concern', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Previous online privacy invasion', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Willing to be profiled online for personalized advertising', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Importance of privacy policies', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Willing to be profiled online for personalized service', elementType: 'Construct'});

  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='50e76544-6451-46cc-881e-b1b690a39c00';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.2307/25148715"}),(g:Model)
  WHERE g.id IN ['50e76544-6451-46cc-881e-b1b690a39c00']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: '50e76544-6451-46cc-881e-b1b690a39c00'}),(e:Element)
  WHERE e.elementName IN ['Importance of information transparency', 'Privacy concern', 'Previous online privacy invasion',  'Willing to be profiled online for personalized advertising', 'Importance of privacy policies',  'Willing to be profiled online for personalized service']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Privacy concern'}),(b:Element {elementName: 'Importance of information transparency'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Previous online privacy invasion'}),(b:Element {elementName: 'Importance of information transparency'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Importance of information transparency'}),(b:Element {elementName: 'Willing to be profiled online for personalized advertising'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Importance of information transparency'}),(b:Element {elementName: 'Willing to be profiled online for personalized service'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Importance of privacy policies'}),(b:Element {elementName: 'Importance of information transparency'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Importance of privacy policies'}),(b:Element {elementName: 'Willing to be profiled online for personalized advertising'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Importance of privacy policies'}),(b:Element {elementName: 'Willing to be profiled online for personalized service'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Privacy concern'}),(b:Element {elementName: 'Willing to be profiled online for personalized advertising'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Privacy concern'}),(b:Element {elementName: 'Willing to be profiled online for personalized service'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Previous online privacy invasion'}),(b:Element {elementName: 'Willing to be profiled online for personalized advertising'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Previous online privacy invasion'}),(b:Element {elementName: 'Willing to be profiled online for personalized service'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;


  // Create the authors
  CREATE (:Author {authorFirst: 'Corey', authorLast: 'Angst', id:"809dbef4-2a03-42d0-8933-bfd52164f7bd"});
  CREATE (:Author {authorFirst: 'M.', authorLast: 'Krishnan', id:"857b5afa-460c-4033-a2a3-8931cc2aff71"});

  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.2307/25148715'}), (a:Author {id: '809dbef4-2a03-42d0-8933-bfd52164f7bd'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148715'}), (a:Author {id: '857b5afa-460c-4033-a2a3-8931cc2aff71'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;

  // Create theories referenced in the publication and related them to elements.
  CREATE (:Theory {theoryTitle: 'Utility maximization theory'});
  MATCH (t:Theory {theoryTitle: 'Utility maximization theory'}), (p:Publication {DOI: '10.2307/25148715'})
  CREATE (p)-[r:DRAWS_ON]->(t)
  RETURN r;
