  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.2307/25148779', citation: "Hui, Teo, & Lee. (2007). The Value of Privacy Assurance: An Exploratory Field Experiment. MIS Quarterly, 31(1), 19."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Privacy assurance', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Personal information disclose', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Monetary incentive', elementType: 'Construct'});
  CREATE (:Element {elementName: 'The amount of information requested', elementType: 'Variable'});

  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='5e6eb890-4442-4432-9407-b906dfeed950';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.2307/25148779"}),(g:Model)
  WHERE g.id IN ['5e6eb890-4442-4432-9407-b906dfeed950']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: '5e6eb890-4442-4432-9407-b906dfeed950'}),(e:Element)
  WHERE e.elementName IN ['Privacy assurance','Personal information disclose', 'Monetary incentive', 'The amount of information requested']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Privacy assurance'}),(b:Element {elementName: 'Personal information disclose'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Monetary incentive'}),(b:Element {elementName: 'Personal information disclose'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'The amount of information requested'}),(b:Element {elementName: 'Personal information disclose'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;

  // Create the authors
  CREATE (:Author {ORCID: '0000-0002-7074-1176',authorFirst: 'Kai-Lung', authorLast: 'Hui', id:"f5a2080f-60a7-47e6-805d-457c5856ed8e"});
  CREATE (:Author {ORCID: '0000-0003-0642-9759',authorFirst: 'Hock Hai', authorLast: 'Teo', id:"d156de17-e00d-4b73-83b3-e1599816933b"});
  CREATE (:Author {ORCID: '0000-0002-1937-3144',authorFirst: 'Sang-Yong Tom', authorLast: 'Lee', id:"cf2e61c3-79af-470f-8917-3583413b6a62"});

  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.2307/25148779'}), (a:Author {id: 'f5a2080f-60a7-47e6-805d-457c5856ed8e'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148779'}), (a:Author {id: 'd156de17-e00d-4b73-83b3-e1599816933b'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148779'}), (a:Author {id: 'cf2e61c3-79af-470f-8917-3583413b6a62'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 3}]->(a)
  RETURN r;
