  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.DefinitionName is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.2307/25148783', citation: "Pavlou, Liang, & Xue. (2007). Understanding and Mitigating Uncertainty in Online Exchange Relationships: A Principal-Agent Perspective. MIS Quarterly, 31(1), 105."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Product diagnosticity', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Trust', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Website informativeness', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Social presence', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Perceived information asymmetry', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Fears of seller opportunism', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Information privacy concerns', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Information security concerns', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Perceived uncertainty', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Purchase involvement', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Purchase intentions', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Actual purchases', elementType: 'Construct'});

  // Create definitions of constructs and concepts
  CREATE (:Definition {DefinitionName: 'Trust', definition:"Trust is defined as the buyer’s intentions to accept vulnerability based on her beliefs that the transaction will meet her confident expectations."});
  CREATE (:Definition {DefinitionName: 'Purchase involvement', definition:"Purchase involvement is defined as the buyer’s perceived relevance with the focal purchase "});
  CREATE (:Definition {DefinitionName: 'Perceived information asymmetry', definition:"Perceived information asymmetry is defined as the buyer’s perception that the seller has a greater quantity or quality of information about its products, characteristics, and selling practices."});
  CREATE (:Definition {DefinitionName: 'Fears of seller opportunism', definition:"Buyer’s fears of seller opportunism are defined as the buyer’s concerns that the seller may act opportunis- tically."});
  CREATE (:Definition {DefinitionName: 'Information privacy concerns', definition:"Infor- mation privacy concerns are defined as a buyer’s beliefs about a seller’s inability and unwillingness to protect her personal information from improper use, disclosure to third parties, and secondary use without the buyer’s consent."});
  CREATE (:Definition {DefinitionName: 'Information security concerns', definition:"Information security concerns are defined as the buyer’s beliefs about a sellers’ inability and unwillingness to safeguard their monetary information from security breaches during transmission and storage (Salisbury et al. 2001)."});
  CREATE (:Definition {DefinitionName: 'Website informativeness', definition:"Website informativeness is defined as the degree to which a website offers information buyers perceive as useful"});
  CREATE (:Definition {DefinitionName: 'Product diagnosticity', definition:"Product diagnosticity is defined as the extent to which a buyer believes that a website is helpful in terms of evaluating a product"});
  CREATE (:Definition {DefinitionName: 'Perceived uncertainty', definition:"Perceived uncertainty refers to the degree by which the outcome of a transaction cannot be accurately predicted"});
  CREATE (:Definition {DefinitionName: 'Social presence', definition:"The concept of social presence is derived from social presence theory (Short et al. 1976), and it refers to the extent to which a medium is perceived as truly conveying the presence of the communicating participants (Rice 1993)."});

  // Create a relationships between a publication and definitions it contains
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Definition {DefinitionName: 'Trust'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Definition {DefinitionName: 'Purchase involvement'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Definition {DefinitionName: 'Perceived information asymmetry'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Definition {DefinitionName: 'Fears of seller opportunism'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Definition {DefinitionName: 'Information privacy concerns'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Definition {DefinitionName: 'Information security concerns'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Definition {DefinitionName: 'Website informativeness'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Definition {DefinitionName: 'Product diagnosticity'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Definition {DefinitionName: 'Perceived uncertainty'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Definition {DefinitionName: 'Social presence'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;

  // Create relationships between definitions and constructs
  MATCH (a:Element {elementName: 'Trust'}), (b:Definition {DefinitionName: 'Trust'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Perceived information asymmetry'}), (b:Definition {DefinitionName: 'Perceived information asymmetry'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Fears of seller opportunism'}), (b:Definition {DefinitionName: 'Fears of seller opportunism'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Information privacy concerns'}), (b:Definition {DefinitionName: 'Information privacy concerns'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Information security concerns'}), (b:Definition {DefinitionName: 'Information security concerns'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Website informativeness'}), (b:Definition {DefinitionName: 'Website informativeness'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Product diagnosticity'}), (b:Definition {DefinitionName: 'Product diagnosticity'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Purchase involvement'}), (b:Definition {DefinitionName: 'Purchase involvement'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Perceived uncertainty'}), (b:Definition {DefinitionName: 'Perceived uncertainty'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Social presence'}), (b:Definition {DefinitionName: 'Social presence'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;

  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='cd4efa75-7a59-4257-940d-b1dbaba97996';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.2307/25148783"}),(g:Model)
  WHERE g.id IN ['cd4efa75-7a59-4257-940d-b1dbaba97996']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: 'cd4efa75-7a59-4257-940d-b1dbaba97996'}),(e:Element)
  WHERE e.elementName IN ['Product diagnosticity', 'Trust', 'Website informativeness', 'Social presence', 'Perceived information asymmetry', 'Fears of seller opportunism','Information privacy concerns', 'Information security concerns', 'Perceived uncertainty', 'Purchase involvement', 'Purchase intentions', 'Actual purchases']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Perceived uncertainty'}),(b:Element {elementName: 'Purchase intentions'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName:  "Perceived uncertainty"}),(b:Element {elementName:  "Purchase involvement"}),(c:Element {elementName: "Purchase intentions"})
  CREATE (a)-[r1:RELATES_TO {type: 'moderates' , model: 'Research model'}]->(b)-[r2:RELATES_TO {type: 'moderates', model: 'Research model'}]->(c)
  RETURN r1, r2;
  MATCH (a:Element {elementName: 'Purchase intentions'}),(b:Element {elementName: 'Actual purchases'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Perceived information asymmetry'}),(b:Element {elementName: 'Perceived uncertainty'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Fears of seller opportunism'}),(b:Element {elementName: 'Perceived uncertainty'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Information privacy concerns'}),(b:Element {elementName: 'Perceived uncertainty'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Information security concerns'}),(b:Element {elementName: 'Perceived uncertainty'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Trust'}),(b:Element {elementName: 'Perceived information asymmetry'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Trust'}),(b:Element {elementName: 'Fears of seller opportunism'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Trust'}),(b:Element {elementName: 'Information privacy concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Trust'}),(b:Element {elementName: 'Information security concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Website informativeness'}),(b:Element {elementName: 'Perceived information asymmetry'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Website informativeness'}),(b:Element {elementName: 'Fears of seller opportunism'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Website informativeness'}),(b:Element {elementName: 'Information privacy concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Website informativeness'}),(b:Element {elementName: 'Information security concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Product diagnosticity'}),(b:Element {elementName: 'Perceived information asymmetry'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Product diagnosticity'}),(b:Element {elementName: 'Fears of seller opportunism'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Social presence'}),(b:Element {elementName: 'Information privacy concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Social presence'}),(b:Element {elementName: 'Information security concerns'})
  CREATE (a)-[r:RELATES_TO {type: 'Causal', model: 'Research model'}]->(b)
  RETURN r;

  // Create the authors
  CREATE (:Author {ORCID: '0000-0002-8830-5727',authorFirst: 'Paul', authorLast: 'Pavlou', id:"90e34755-531e-47b0-89f2-c3489b200e76"});
  CREATE (:Author {authorFirst: 'Huigang', authorLast: 'Liang', id:"4ad6cb7d-5c6c-4485-96be-17977e90f73e"});
  CREATE (:Author {authorFirst: 'Yajiong', authorLast: 'Xue', id:"a67f30f6-c71b-4899-946b-1c6bdb6da199"});


  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Author {id: '90e34755-531e-47b0-89f2-c3489b200e76'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Author {id: '4ad6cb7d-5c6c-4485-96be-17977e90f73e'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148783'}), (a:Author {id: 'a67f30f6-c71b-4899-946b-1c6bdb6da199'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 3}]->(a)
  RETURN r;

  // Create theories referenced in the publication and related them to elements.
  CREATE (:Theory {theoryTitle: 'Agency theory'});
  MATCH (t:Theory {theoryTitle: 'Agency theory'}), (p:Publication {DOI: '10.2307/25148783'})
  CREATE (p)-[r:DRAWS_ON]->(t)
  RETURN r;
  CREATE (:Theory {theoryTitle: 'Social presence theory'});
  MATCH (t:Theory {theoryTitle: 'Social presence theory'}), (e:Element {elementName: 'Social presence'})
  CREATE (t)-[r:Informs]->(e)
  RETURN r;
