  // Author: April <yuanyuan.song@uga.edu>
  // Dec 2020
  // Create constraints on Element, ORCID, definition, DOI, id

  CREATE constraint on (a:Element) ASSERT a.elementName is unique;
  CREATE constraint on (a:Definition) ASSERT a.id is unique;
  CREATE constraint on (a:Publication) ASSERT a.DOI is unique;
  CREATE constraint on (a:Publication) ASSERT a.ISBN is unique;
  CREATE constraint on (a:Model) ASSERT a.id is unique;
  CREATE constraint on (a:Author) ASSERT a.ORCID is unique;
  CREATE constraint on (a:Author) ASSERT a.id is unique;
  CREATE constraint on (a:Theory) ASSERT a.theoryTitle is unique;

  //Create a publication with properties for DOI (document object identifier) and the citation.
  //When implemented, the DOI API (https://support.datacite.org/docs/api-get-doi) would be used populate properties discretely, such as journal title

  CREATE (:Publication {DOI: '10.2307/25148854', citation: "Son, J. Y., & Kim, S. S. (2008). Internet users' information privacy-protective responses: A taxonomy and a nomological model. MIS quarterly, 503-529."});

  // Create each element with a property of elementName and elementType
  CREATE (:Element {elementName: 'Information privacy concerns', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Perceived justice', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Societal benefits from complaining', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Refusal', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Misrepresentation', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Removal', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Negative word-of-mouth', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Complaining indirectly to third-party organizations', elementType: 'Construct'});
  CREATE (:Element {elementName: 'Complaining directly to third-party organizations', elementType: 'Construct'});


  // Create definitions of constructs and concepts
  CREATE (:Definition {DefinitionName: 'Information privacy concerns', definition:"Degree to which an Internet user is concerned about online companies’ practices related to the collection and use of his or her personal information",id:"06df4c3f-b365-4ae2-ac04-c8745f043d6d"});
  CREATE (:Definition {DefinitionName: 'Perceived justice', definition:"Degree of fairness that an Internet user perceives about online companies’ treatment related to information privacy",id:"e3025bf7-b1b5-445a-9cb0-2e7923e4d104"});
  CREATE (:Definition {DefinitionName: 'Societal benefits from complaining', definition:"Degree to which an Internet user perceives that complaining about privacy invasions will benefit other Internet users by preventing them from being similarly victimized",id:"87a50cc1-a04f-4a69-a454-b4738424c4f3"});

  // Create a relationships between a publication and definitions it contains
  MATCH (p:Publication {DOI: '10.2307/25148854'}), (a:Definition {id: '06df4c3f-b365-4ae2-ac04-c8745f043d6d'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148854'}), (a:Definition {id: 'e3025bf7-b1b5-445a-9cb0-2e7923e4d104'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148854'}), (a:Definition {id: '87a50cc1-a04f-4a69-a454-b4738424c4f3'})
  CREATE (p)-[r:DEFINES]->(a)
  RETURN r;

  // Create relationships between definitions and constructs
  MATCH (a:Element {elementName: 'Information privacy concerns'}), (b:Definition {id: '06df4c3f-b365-4ae2-ac04-c8745f043d6d'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Perceived justice'}), (b:Definition {id: 'e3025bf7-b1b5-445a-9cb0-2e7923e4d104'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Societal benefits from complaining'}), (b:Definition {id: '87a50cc1-a04f-4a69-a454-b4738424c4f3'})
  CREATE (a)-[r:DEFINED_AS]->(b)
  RETURN r;

  // Create a model for each model in the publication
  // Set up the id
  CREATE (g:Model {modelTitle: 'Research model'})
  SET g.id='c5cf69f5-7552-4a7e-8235-757ca20d6cdc';
  // Find the last id created
  // MATCH (g:Model)
  // WHERE EXISTS (g.createtime) // ignore those without a timestamp
  // RETURN g.id
  // ORDER by g.createtime DESC
  // LIMIT 1;

  // Here we need to run the above part first in neo4j. Then copy and paste the returned id into the following code. Then we can run the rest of the code.

  // Create the relationships between publication and the 'Research model' using model ID
  MATCH (p:Publication {DOI: "10.2307/25148854"}),(g:Model)
  WHERE g.id IN ['c5cf69f5-7552-4a7e-8235-757ca20d6cdc']
  CREATE (p)-[r:CONTAINS]->(g)
  RETURN r;

  // Create the relationships between the elements and the 'Research model' using model ID
  MATCH (g:Model {id: 'c5cf69f5-7552-4a7e-8235-757ca20d6cdc'}),(e:Element)
  WHERE e.elementName IN ['Information privacy concerns','Perceived justice', 'Societal benefits from complaining', 'Refusal', 'Misrepresentation', 'Removal', 'Negative word-of-mouth', 'Complaining indirectly to third-party organizations', 'Complaining directly to third-party organizations']
  CREATE (g)-[r:DEPICTS]->(e)
  RETURN r;

  // Create relationships among elements
  MATCH (a:Element {elementName: 'Information privacy concerns'}),(b:Element {elementName: 'Refusal'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Information privacy concerns'}),(b:Element {elementName: 'Misrepresentation'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Information privacy concerns'}),(b:Element {elementName: 'Removal'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Information privacy concerns'}),(b:Element {elementName: 'Negative word-of-mouth'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Information privacy concerns'}),(b:Element {elementName: 'Complaining indirectly to third-party organizations'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Information privacy concerns'}),(b:Element {elementName: 'Complaining directly to third-party organizations'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Perceived justice'}),(b:Element {elementName: 'Refusal'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Perceived justice'}),(b:Element {elementName: 'Misrepresentation'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Societal benefits from complaining'}),(b:Element {elementName: 'Complaining indirectly to third-party organizations'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;
  MATCH (a:Element {elementName: 'Societal benefits from complaining'}),(b:Element {elementName: 'Complaining directly to third-party organizations'})
  CREATE (a)-[r:RELATES_TO {type: 'causal', model: 'Research model'}]->(b)
  RETURN r;

  // Create the authors
  CREATE (:Author {ORCID: '0000-0002-1216-2854',authorFirst: 'Jai-Yeol', authorLast: 'Son', id:"a907ab6c-8be9-42f8-a8af-b4ecd72a4a74"});
  CREATE (:Author {authorFirst: 'Sung', authorLast: 'Kim', id:"7654e54a-4221-4361-b541-7ba7ed1b2e98"});

  // Create the relationships between the authors and publication with authorOrder as a property of the relationship
  MATCH (p:Publication {DOI: '10.2307/25148854'}), (a:Author {id: 'a907ab6c-8be9-42f8-a8af-b4ecd72a4a74'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 1}]->(a)
  RETURN r;
  MATCH (p:Publication {DOI: '10.2307/25148854'}), (a:Author {id: '7654e54a-4221-4361-b541-7ba7ed1b2e98'})
  CREATE (p)-[r:WRITTEN_BY {authorOrder: 2}]->(a)
  RETURN r;
